@@ -10,9 +10,9 @@ TODO:
 # License: BSD Style.
 
 import warnings
-import sys
-PY_VER = sys.version_info[0]
-import builtins
+
+import six
+import six.moves.builtins
 
 from traits.api import (HasTraits, List, Str, Dict, Bool,
         Unicode, Property, Int, Instance)
@@ -223,7 +223,7 @@ class Recorder(HasTraits):
 
             sub_recordables = list(object.traits(record=True).keys())
             # Find all the trait names we must ignore.
-            ignore.extend(list(object.traits(record=False).keys()))
+            ignore.extend(object.traits(record=False).keys())
             # The traits to listen for.
             tnames = [t for t in object.trait_names()
                       if not t.startswith('_') and not t.endswith('_') \
@@ -373,10 +373,10 @@ class Recorder(HasTraits):
         """Save the recorded lines to the given file.  It does not close
         the file.
         """
-        if PY_VER == 3:
+        if six.PY3:
             file.write(self.get_code())
         else:
-            file.write(str(self.get_code(), encoding='utf-8'))
+            file.write(six.text_type(self.get_code(), encoding='utf-8'))
         file.flush()
 
     def record_function(self, func, args, kw):
@@ -503,7 +503,7 @@ class Recorder(HasTraits):
         nm = self._name_map
         result = ''
         builtin = False
-        if cname in builtins.__dict__:
+        if cname in six.moves.builtins.__dict__:
             builtin = True
             if hasattr(obj, '__name__'):
                 cname = obj.__name__
@@ -691,7 +691,7 @@ class Recorder(HasTraits):
         """Return a string given a returned object from a function.
         """
         result = ''
-        long_type = int if PY_VER == 2 else int
+        long_type = long if six.PY2 else int
         ignore = (float, complex, bool, int, long_type, str)
         if object is not None and type(object) not in ignore:
             # If object is not know, register it.
@@ -710,7 +710,7 @@ class Recorder(HasTraits):
         """
         cname = cls.__name__
         result = ''
-        if cname not in builtins.__dict__:
+        if cname not in six.moves.builtins.__dict__:
             mod = cls.__module__
             typename = '%s.%s'%(mod, cname)
             if typename not in self._known_types:
